package org.activemq.usecases;

public class TopicSystemTest extends SystemTest {

    /**
     * Sets up the resources of the unit test.
     *
     * @throws Exception
     */
    protected void setUp() throws Exception {
        System.out.println("############################################################");
        System.out.println("TopicSystemTest.setUp()...");
        super.setUp();
    }

    /**
     * Clears up the resources used in the unit test.
     */
    protected void tearDown() throws Exception {
        System.out.println("TopicSystemTest.tearDown()...");
        System.out.println("############################################################");
        super.tearDown();
    }

    /**
     * Unit test for persistent durable topic messages with the following settings:
     * 1 Producer, 1 Consumer, 1 Subject, 10 Messages
     *
     * @throws Exception
     */
    public void testPersistentDurableTopicMessageA() throws Exception {
        SystemTest st = new SystemTest(true,
                                       true,
                                       true,
                                       1,
                                       1,
                                       1,
                                       10,
                                       "testPersistentDurableTopicMessageA()");
        st.doTest();
    }

    /**
     * Unit test for persistent durable topic messages with the following settings:
     * 10 Producers, 10 Consumers, 1 Subject, 10 Messages
     *
     * @throws Exception
     */
    public void testPersistentDurableTopicMessageB() throws Exception{
        SystemTest st = new SystemTest(true,
                                       true,
                                       true,
                                       10,
                                       10,
                                       1,
                                       10,
                                       "testPersistentDurableTopicMessageB()");
        st.doTest();
    }

    /**
     * Unit test for persistent durable topic messages with the following settings:
     * 10 Producers, 10 Consumers, 10 Subjects, 10 Messages
     *
     * @throws Exception
     */
    public void testPersistentDurableTopicMessageC() throws Exception{
        SystemTest st = new SystemTest(true,
                                       true,
                                       true,
                                       10,
                                       10,
                                       10,
                                       10,
                                       "testPersistentDurableTopicMessageC()");
        st.doTest();
     }


    /**
     * Unit test for persistent non-durable topic messages with the following settings:
     * 1 Producer, 1 Consumer, 1 Subject, 10 Messages
     *
     * @throws Exception
     */
    public void testPersistentNonDurableTopicMessageA() throws Exception{
        SystemTest st = new SystemTest(true,
                                       true,
                                       false,
                                       1,
                                       1,
                                       1,
                                       10,
                                       "testPersistentNonDurableTopicMessageA()");
        st.doTest();
    }

    /**
     * Unit test for persistent non-durable topic messages with the following settings:
     * 10 Producers, 10 Consumers, 1 Subject, 10 Messages
     *
     * @throws Exception
     */
    public void testPersistentNonDurableTopicMessageB() throws Exception{
        SystemTest st = new SystemTest(true,
                                       true,
                                       false,
                                       10,
                                       10,
                                       1,
                                       10,
                                       "testPersistentNonDurableTopicMessageB()");
        st.doTest();
    }

    /**
     * Unit test for persistent non-durable topic messages with the following settings:
     * 10 Producers, 10 Consumers, 10 Subjects, 10 Messages
     *
     * @throws Exception
     */
    public void testPersistentNonDurableTopicMessageC() throws Exception{
        SystemTest st = new SystemTest(true,
                                       true,
                                       false,
                                       10,
                                       10,
                                       10,
                                       10,
                                       "testPersistentNonDurableTopicMessageC()");
        st.doTest();
    }

    /**
     * Unit test for non-persistent durable topic messages with the following settings:
     * 1 Producer, 1 Consumer, 1 Subject, 10 Messages
     *
     * @throws Exception
     */
    public void testNonPersistentDurableTopicMessageA() throws Exception{
        SystemTest st = new SystemTest(true,
                                       false,
                                       true,
                                       1,
                                       1,
                                       1,
                                       10,
                                       "testNonPersistentDurableTopicMessageA()");
        st.doTest();
    }

    /**
     * Unit test for non-persistent durable topic messages with the following settings:
     * 10 Producers, 10 Consumers, 1 Subject, 10 Messages
     *
     * @throws Exception
     */
    public void testNonPersistentDurableTopicMessageB() throws Exception{
        SystemTest st = new SystemTest(true,
                                       false,
                                       true,
                                       10,
                                       10,
                                       1,
                                       10,
                                       "testNonPersistentDurableTopicMessageB()");
        st.doTest();
    }

    /**
     * Unit test for non-persistent durable topic messages with the following settings:
     * 10 Producers, 10 Consumers, 10 Subjects, 10 Messages
     *
     * @throws Exception
     */
    public void testNonPersistentDurableTopicMessageC() throws Exception{
        SystemTest st = new SystemTest(true,
                                       false,
                                       true,
                                       10,
                                       10,
                                       10,
                                       10,
                                       "testNonPersistentDurableTopicMessageC()");
        st.doTest();
    }

    /**
     * Unit test for non-persistent non-durable topic messages with the following settings:
     * 1 Producer, 1 Consumer, 1 Subject, 10 Messages
     *
     * @throws Exception
     */
    public void testNonPersistentNonDurableTopicMessageA() throws Exception{
        SystemTest st = new SystemTest(true,
                                       false,
                                       false,
                                       1,
                                       1,
                                       1,
                                       10,
                                       "testNonPersistentNonDurableTopicMessageA()");
        st.doTest();
    }

    /**
     * Unit test for non-persistent non-durable topic messages with the following settings:
     * 10 Producers, 10 Consumers, 1 Subject, 10 Messages
     *
     * @throws Exception
     */
    public void testNonPersistentNonDurableTopicMessageB() throws Exception{
        SystemTest st = new SystemTest(true,
                                       false,
                                       false,
                                       10,
                                       10,
                                       1,
                                       10,
                                       "testNonPersistentNonDurableTopicMessageB()");
        st.doTest();
    }

    /**
     * Unit test for non-persistent non-durable topic messages with the following settings:
     * 10 Producers, 10 Consumers, 10 Subjects, 10 Messages
     *
     * @throws Exception
     */
    public void testNonPersistentNonDurableTopicMessageC() throws Exception{
        SystemTest st = new SystemTest(true,
                                       false,
                                       false,
                                       10,
                                       10,
                                       10,
                                       10,
                                       "testNonPersistentNonDurableTopicMessageC()");
        st.doTest();
    }
}